======
 Done
======

> Public Release 0.6 : October 3, 2008

- include a patch for pymacs signal bug : October 3, 2008
- set next-error-function : July 16, 2008

> Public Release 0.6c2 : June 20, 2008

- fixed go to occurrence in xemacs : June 20, 2008
- added ropemacs-guess-project variable : June 18, 2008
- fixed error messages that contain percent sign : June 18, 2008
- fixed ask directory and entering default directory : June 9, 2008
- added rope-run-module command : May 24, 2008
- showing line-number in occurrences buffer : May 19, 2008

> Public Release 0.6c1 : May 10, 2008

- supporting inlining parameters : May 10, 2008
- added rope-change-signature : May 9, 2008
- added ropemacs-autoimport-underlineds variable : May 7, 2008
- added rope-find-implementations : April 28, 2008
- added rope-show-calltip : April 12, 2008
- added rope-analyze-modules : April 12, 2008

> Public Release 0.5 : April 5, 2008

- better input error reporting : March 27, 2008
- added ropemacs-completing-read-function variable : March 17, 2008
- added rope-jump-to-global : March 17, 2008

> Public Release 0.5c6 : March 15, 2008

- added rope-analyze-module command : March 15, 2008
- supporting in_hierarchy option of find_occurrences : March 10, 2008
- added ropemacs-max-doc-buffer-height variable : March 7, 2008
- added ropemacs menu : March 7, 2008
- added rope-show-call-doc command : March 6, 2008
- added ropemacs-separate-doc-buffer variable : March 6, 2008
- supporting maxfixes option of rope-goto-definition : March 6, 2008
- supporting maxfixes option of rope-show-doc : March 6, 2008
- added ropemacs minor mode : March 1, 2008

> Public Release 0.5c5 : March 1, 2008

- filtering resources : February 29, 2008
- added support for introduce factory refactoring : February 25, 2008

> Public Release 0.5c4 : February 16, 2008

- compatibility with pymacs : February 14, 2008
- faster code-assists : February 7, 2008
- prefixing rope-find-file shows only python files : February 2, 2008
- merged rope-complete-and-import with code-assist : January 28, 2008

> Public Release 0.5c3 : January 28, 2008

- added support for autoimport : January 26, 2008
- added introduce method object refactoring : January 25, 2008
- added use function refactoring : January 25, 2008

> Public Release 0.5c2 : January 17, 2008

- showing change description in undo/redo : January 8, 2008
- added rope-find-file-other-window : January 4, 2008
- added ropemacs-enable-shortcuts variable : January 3, 2008

> Public Release 0.5c1 : January 3, 2008

- deprecated rope-code-assist-max-fixes : December 28, 2007
- deprecated rope-confirm-saving : December 28, 2007
- added ropemacs-local-prefix and ropemacs-global-prefix : December 28, 2007
- handling narrowed regions : December 21, 2007

> Public Release 0.4 : December 19, 2007

- supporting emacs 21 : December 18, 2007
- added ``rope-code-assist-max-fixes`` variable : December 17, 2007
- printing traceback when task runner gets interrupted : December 14, 2007
- supporting ``only_current`` option for inline refactoring : December 13, 2007
- supporting ``global_`` option for extract refactorings : December 13, 2007
- not raising exceptions in hooks : December 5, 2007

> Public Release 0.3 : December 5, 2007

- setting many configs using batchset in dialogs : December 1, 2007
- updating buffers with moved files : December 1, 2007
- showing the old value of a field in dialogs : November 30, 2007
- new file/directory/module/package; ``C-x p n [fdmp]`` : November 30, 2007
- lucky-assist; ``M-?`` : November 29, 2007
- find occurrences; ``C-c f`` : November 29, 2007
- edit project config; ``C-x p c`` : November 28, 2007

> Public Release 0.2 : November 28, 2007

- previewing changes : November 27, 2007
- specifying refactoring options : November 26, 2007
- restructuring support : November 26, 2007
- added ``rope-confirm-saving`` variable : November 26, 2007
- only activating local keys in python mode : November 26, 2007
- find file and advanced matching : November 25, 2007
- generate python element; ``C-c n [vfcmp]`` : November 23, 2007
- rope find file; ``C-c p f`` : November 23, 2007
- code-assist; ``M-/`` : November 23, 2007

> Public Release 0.1 : September 9, 2007

- moving elements, methods and modules : October 30, 2007
- undoing refactorings : October 29, 2007
- inline refactoring : October 29, 2007
- extract method and local variable : October 29, 2007
- goto definition : October 29, 2007
- rename refactoring : October 29, 2007
